@@ -22,7 +22,6 @@
 #include "contacteditor.h"
 
 #include "abstractcontacteditorwidget_p.h"
-#include "autoqpointer_p.h"
 #include "contactmetadataakonadi_p.h"
 #include "attributes/contactmetadataattribute_p.h"
 #include "editor/contacteditorwidget.h"
@@ -79,19 +78,21 @@ public:
     void storeContact(KContacts::Addressee &addr, ContactMetaDataAkonadi &metaData);
     void setupMonitor();
 
-    AkonadiContactEditor *mParent;
+    AkonadiContactEditor *mParent = nullptr;
     AkonadiContactEditor::Mode mMode;
     Akonadi::Item mItem;
     Akonadi::ContactMetaDataAkonadi mContactMetaData;
-    Akonadi::Monitor *mMonitor;
+    Akonadi::Monitor *mMonitor = nullptr;
     Akonadi::Collection mDefaultCollection;
-    ContactEditor::AbstractContactEditorWidget *mEditorWidget;
-    bool mReadOnly;
+    ContactEditor::AbstractContactEditorWidget *mEditorWidget = nullptr;
+    bool mReadOnly = false;
 };
 
 void Akonadi::AkonadiContactEditor::Private::itemFetchDone(KJob *job)
 {
     if (job->error() != KJob::NoError) {
+        Q_EMIT mParent->error(job->errorString());
+        Q_EMIT mParent->finished();
         return;
     }
 
@@ -113,8 +114,9 @@ void Akonadi::AkonadiContactEditor::Private::itemFetchDone(KJob *job)
 
         Akonadi::CollectionFetchJob *collectionFetchJob = new Akonadi::CollectionFetchJob(mItem.parentCollection(),
                                                                                           Akonadi::CollectionFetchJob::Base);
-        mParent->connect(collectionFetchJob, SIGNAL(result(KJob *)),
-                         SLOT(parentCollectionFetchDone(KJob *)));
+        mParent->connect(collectionFetchJob, &CollectionFetchJob::result, mParent, [this](KJob *job) {
+            parentCollectionFetchDone(job);
+        });
     } else {
         const KContacts::Addressee addr = mItem.payload<KContacts::Addressee>();
         mContactMetaData.load(mItem);
@@ -126,6 +128,8 @@ void Akonadi::AkonadiContactEditor::Private::itemFetchDone(KJob *job)
 void Akonadi::AkonadiContactEditor::Private::parentCollectionFetchDone(KJob *job)
 {
     if (job->error()) {
+        Q_EMIT mParent->error(job->errorString());
+        Q_EMIT mParent->finished();
         return;
     }
 
@@ -139,11 +143,10 @@ void Akonadi::AkonadiContactEditor::Private::parentCollectionFetchDone(KJob *job
         mReadOnly = !(parentCollection.rights() & Collection::CanChangeItem);
     }
 
-    mEditorWidget->setReadOnly(mReadOnly);
-
     const KContacts::Addressee addr = mItem.payload<KContacts::Addressee>();
     mContactMetaData.load(mItem);
     loadContact(addr, mContactMetaData);
+    mEditorWidget->setReadOnly(mReadOnly);
 }
 
 void Akonadi::AkonadiContactEditor::Private::storeDone(KJob *job)
@@ -177,7 +180,9 @@ void Akonadi::AkonadiContactEditor::Private::itemChanged(const Akonadi::Item &it
         job->fetchScope().fetchAttribute<ContactMetaDataAttribute>();
         job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 
-        mParent->connect(job, SIGNAL(result(KJob *)), mParent, SLOT(itemFetchDone(KJob *)));
+        mParent->connect(job, &ItemFetchJob::result, mParent, [this](KJob *job) {
+            itemFetchDone(job);
+        });
     }
 
     delete dlg;
@@ -197,9 +202,13 @@ void Akonadi::AkonadiContactEditor::Private::setupMonitor()
 {
     delete mMonitor;
     mMonitor = new Akonadi::Monitor;
+    mMonitor->setObjectName(QStringLiteral("ContactEditorMonitor"));
     mMonitor->ignoreSession(Akonadi::Session::defaultSession());
 
-    connect(mMonitor, SIGNAL(itemChanged(Akonadi::Item,QSet<QByteArray>)), mParent, SLOT(itemChanged(Akonadi::Item,QSet<QByteArray>)));
+    connect(mMonitor, &Monitor::itemChanged, mParent,
+            [this](const Akonadi::Item &item, const QSet<QByteArray> &set) {
+        itemChanged(item, set);
+    });
 }
 
 Akonadi::AkonadiContactEditor::AkonadiContactEditor(Mode mode, QWidget *parent)
@@ -236,7 +245,9 @@ void Akonadi::AkonadiContactEditor::loadContact(const Akonadi::Item &item)
     job->fetchScope().fetchAttribute<ContactMetaDataAttribute>();
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 
-    connect(job, SIGNAL(result(KJob *)), SLOT(itemFetchDone(KJob *)));
+    connect(job, &ItemFetchJob::result, this, [this](KJob *job) {
+        d->itemFetchDone(job);
+    });
 
     d->setupMonitor();
     d->mMonitor->setItemMonitored(item);
@@ -266,19 +277,23 @@ void Akonadi::AkonadiContactEditor::saveContactInAddressBook()
         d->mItem.setPayload<KContacts::Addressee>(addr);
 
         Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(d->mItem);
-        connect(job, SIGNAL(result(KJob *)), SLOT(storeDone(KJob *)));
+        connect(job, &ItemModifyJob::result, this, [this](KJob *job) {
+            d->storeDone(job);
+        });
     } else if (d->mMode == CreateMode) {
         if (!d->mDefaultCollection.isValid()) {
             const QStringList mimeTypeFilter(KContacts::Addressee::mimeType());
 
-            AutoQPointer<CollectionDialog> dlg = new CollectionDialog(this);
+            QPointer<CollectionDialog> dlg = new CollectionDialog(this);
             dlg->setMimeTypeFilter(mimeTypeFilter);
             dlg->setAccessRightsFilter(Collection::CanCreateItem);
             dlg->setWindowTitle(i18n("Select Address Book"));
             dlg->setDescription(i18n("Select the address book the new contact shall be saved in:"));
             if (dlg->exec() == QDialog::Accepted) {
                 setDefaultAddressBook(dlg->selectedCollection());
+                delete dlg;
             } else {
+                delete dlg;
                 return;
             }
         }
@@ -293,7 +308,9 @@ void Akonadi::AkonadiContactEditor::saveContactInAddressBook()
         d->mContactMetaData.store(item);
 
         Akonadi::ItemCreateJob *job = new Akonadi::ItemCreateJob(item, d->mDefaultCollection);
-        connect(job, SIGNAL(result(KJob *)), SLOT(storeDone(KJob *)));
+        connect(job, &ItemCreateJob::result, this, [this](KJob *job) {
+            d->storeDone(job);
+        });
     }
 }
 
