@@ -74,7 +74,7 @@ public:
     /**
      * Destroys the widget lister.
      */
-    virtual ~KWidgetLister();
+    ~KWidgetLister() override;
 
 protected Q_SLOTS:
     /**
